==> nextcloud-12.0.5.tar.bz2: nextcloud/apps/gallery/l10n/id.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Galeri",
    "There was a problem reading files from this album" : "Terjadi masalah saat membaca berkas dari album ini",
    "Aborting preview. Could not find the file" : "Membatalkan pratinjau. Tidak dapat menemukan berkas.",
    "Could not move \"{file}\", target exists" : "Tidak dapat memindahkan \"{file}\", sudah ada",
    "Could not move \"{file}\"" : "Tidak dapat memindahkan \"{file}\"",
    "No compatible server found at {remote}" : "Tida ditemukan server yang kompatibel pada {remote}",
    "Invalid server url" : "URL server salah",
    "Could not load the description" : "Tidak dapat memuat deskripsi",
    "Could not load the description: " : "Tidak dapat memuat deskripsi:",
    "Copyright" : "Hak cipta",
    "Could not load the copyright notice: " : "Tidak dapat memuat pernyataan hak cipta:",
    "Copyright notice" : "Pernyataan hak cipta",
    "Link to copyright document" : "Taut ke dokumen hak cipta",
    "This application may not work properly on your browser." : "Aplikasi ini mungkin tidak dapat bekerja dengan benar pada peramban Anda.",
    "For an improved experience, please install one of the following alternatives" : "Untuk meningkatkan pengalaman, silakan pasang salah satu alternatif berikut",
    "Your browser is not supported!" : "Peramban Anda tidak didukung!",
    "please install one of the following alternatives" : "silakan pasang salah satu alternatif berikut",
    "Album cannot be shown" : "Album tidak dapat ditampilkan",
    "No media files found" : "Tidak ditemukan berkas media",
    "Upload new files via drag and drop or by using the [+] button above" : "Unggah berkas baru melalui drag dan drop atau menggunakan tombol [+] diatas",
    "Configuration error" : "Kesalahan konfigurasi",
    "New" : "Baru",
    "Hide Album" : "Sembunyikan Album",
    "Could not hide album" : "Tidka dapat menyembunyikan album",
    "Error loading slideshow template" : "Kesalahan saat memuat templat slideshow",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>Galat!</strong> Tidak dapat membuat pratinjau dari berkas ini.<br>Mohon lanjutkan ke slide berikutnya saat kami menghapus gambar ini dari slideshow",
    "Next" : "Berikutnya",
    "Play" : "Putar",
    "Pause" : "Jeda",
    "Previous" : "Sebelumnya",
    "Close" : "Tutup",
    "Download" : "Unduh",
    "Toggle background" : "Ubah latar belakang",
    "Delete" : "Hapus",
    "Share" : "Bagikan",
    "Could not create file \"{file}\" because it already exists" : "Tidak dapat membuat berkas \"{file}\" karena sudah ada",
    "Could not create file \"{file}\"" : "Tidak dapat membuat berkas \"{file}\"",
    "\"{name}\" is an invalid file name." : "\"{name}\" adalah nama berkas yang tidak sah.",
    "File name cannot be empty." : "Nama berkas tidak boleh kosong.",
    "Upload" : "Unggah",
    "Error" : "Kesalahan",
    "Error while sharing" : "Kesalahan saat membagikan",
    "Error while unsharing" : "Kesalahan saat membatalkan pembagian",
    "Error while changing permissions" : "Kesalahan saat mengubah izin",
    "Shared with you and the group {group} by {owner}" : "Dibagikan dengan anda dan grup {group} oleh {owner}",
    "Shared with you by {owner}" : "Dibagikan dengan anda oleh {owner}",
    "Share with users or groups …" : "Bagikan dengan pengguna atau grup ...",
    "Share with users, groups or remote users …" : "Bagikan dengan pengguna, grup atau pengguna remote ...",
    "Share with people on other servers using their Federated Cloud ID username@example.com/cloud" : "Bagikan dengan orang diserver lainnya dengan menggunakan Federated Cloud ID orang tersebut username@example.com/cloud",
    "Share link" : "Bagikan tautan",
    "The public link will expire no later than {days} days after it is created" : "Tautan publik akan kadaluarsa tidak lebih dari {days} hari setelah ini dibuat",
    "Link" : "Tautan",
    "Password protect" : "Lindungi dengan sandi",
    "Password" : "Kata Sandi",
    "Choose a password for the public link" : "Tetapkan sandi untuk tautan publik",
    "Allow editing" : "Izinkan penyuntingan",
    "Email link to person" : "Emailkan tautan ini ke orang",
    "Send" : "Kirim",
    "Set expiration date" : "Atur tanggal kedaluwarsa",
    "Expiration" : "Kedaluwarsa",
    "Expiration date" : "Tanggal kedaluwarsa",
    "An error occured. Please try again" : "Terjadi masalah. Mohon coba kembali",
    "Adding user..." : "Menambahkan pengguna...",
    "group" : "grup",
    "remote" : "remote",
    "Resharing is not allowed" : "Berbagi ulang tidak diizinkan",
    "Error while retrieving shares" : "Terjadi kesalahan saat mengambil pembagian",
    "Unshare" : "Batalkan berbagi",
    "notify by email" : "notifikasi via email",
    "can share" : "dapat berbagi",
    "can edit" : "dapat disunting",
    "access control" : "kontrol akses",
    "create" : "buat",
    "change" : "ubah",
    "delete" : "hapus",
    "Password protected" : "Sandi dilindungi",
    "Error unsetting expiration date" : "Kesalahan saat menghapus tanggal kedaluwarsa",
    "Error setting expiration date" : "Kesalahan saat mengatur tanggal kedaluwarsa",
    "Sending ..." : "Mengirim ...",
    "Email sent" : "Email terkirim",
    "Warning" : "Peringatan",
    "This share is password-protected" : "Berbagi ini dilindungi sandi",
    "The password is wrong. Try again." : "Sandi salah. Coba lagi",
    "Sort by name" : "Urutkan berdasarkan nama",
    "Sort by date" : "Urutkan berdasarkan tanggal",
    "Cancel upload" : "Batal unggah",
    "Album information" : "Informasi album",
    "File list" : "Daftar berkas",
    "Sorry, this file could not be found." : "Maaf, berkas ini tidak akan ditemukan.",
    "Reasons might be:" : "Alasan yang mungkin:",
    "the wrong file ID was provided" : "ID berkas yang diberikan salah",
    "the file was removed" : "berkas tersebut telah dihapus",
    "the file is corrupt" : "berkas tersebut rusak",
    "the encryption key is missing" : "kunci enkripsi tidak ada",
    "Here is the error message returned by the server: " : "Disini merupakan pesan kesalahan yang dikembalikan oleh server:",
    "For more information, please contact your friendly Nextcloud administrator." : "Untuk info lebih lanjut, harap hubungi administrator Nextcloud anda.",
    "Sorry, but the server could not fulfill your request." : "Maaf, tetapi server tidak dapat memenuhi permintaan Anda.",
    "Possible reasons for the problem:" : "Penyebab masalah yang mungkin:",
    "a conflicting app was installed" : "sebuah aplikasi yang dipasang menyebabkan konflik",
    "a required component is missing or was disconnected" : "sebuah komponen yang diperlukan tidak ada atau telah terputus",
    "the filesystem is not readable" : "sistem berkas tidak dapat dibaca",
    "Sorry, this link doesn't seem to work anymore." : "Maaf, tautan ini tampaknya tidak bekerja lagi.",
    "the item was removed" : "item telah dihapus",
    "the link has expired" : "tautan telah kadaluarsa",
    "sharing is disabled" : "berbagi dinonaktifkan",
    "For more information, please ask the person who has sent you this link." : "Untuk informasi lebih lanjut, silakan tanyakan pada orang yang telah mengirimkan Anda tautan ini.",
    "Add to your Nextcloud" : "Tambahkan ke Nextcloud Anda",
    "Picture view" : "Tampilan gambar",
    "Gallery view" : "Tampilan galeri"
},
"nplurals=1; plural=0;");

==> nextcloud-15.0.11.tar.bz2: nextcloud/apps/gallery/l10n/id.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Galeri",
    "There was a problem reading files from this album" : "Terjadi masalah saat membaca berkas dari album ini",
    "Aborting preview. Could not find the file" : "Membatalkan pratinjau. Tidak dapat menemukan berkas.",
    "Could not move \"{file}\", target exists" : "Tidak dapat memindahkan \"{file}\", sudah ada",
    "Could not move \"{file}\"" : "Tidak dapat memindahkan \"{file}\"",
    "No compatible server found at {remote}" : "Tida ditemukan server yang kompatibel pada {remote}",
    "Invalid server url" : "URL server salah",
    "Could not load the description" : "Tidak dapat memuat deskripsi",
    "Could not load the description: " : "Tidak dapat memuat deskripsi:",
    "Copyright" : "Hak cipta",
    "Could not load the copyright notice: " : "Tidak dapat memuat pernyataan hak cipta:",
    "Copyright notice" : "Pernyataan hak cipta",
    "Link to copyright document" : "Taut ke dokumen hak cipta",
    "This application may not work properly on your browser." : "Aplikasi ini mungkin tidak dapat bekerja dengan benar pada peramban Anda.",
    "For an improved experience, please install one of the following alternatives" : "Untuk meningkatkan pengalaman, silakan pasang salah satu alternatif berikut",
    "Your browser is not supported!" : "Peramban Anda tidak didukung!",
    "please install one of the following alternatives" : "silakan pasang salah satu alternatif berikut",
    "Album cannot be shown" : "Album tidak dapat ditampilkan",
    "No media files found" : "Tidak ditemukan berkas media",
    "Upload new files via drag and drop or by using the [+] button above" : "Unggah berkas baru melalui drag dan drop atau menggunakan tombol [+] diatas",
    "Configuration error" : "Kesalahan konfigurasi",
    "Hide Album" : "Sembunyikan Album",
    "Could not hide album" : "Tidka dapat menyembunyikan album",
    "Error loading slideshow template" : "Kesalahan saat memuat templat slideshow",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>Galat!</strong> Tidak dapat membuat pratinjau dari berkas ini.<br>Mohon lanjutkan ke slide berikutnya saat kami menghapus gambar ini dari slideshow",
    "Next" : "Berikutnya",
    "Play" : "Putar",
    "Pause" : "Jeda",
    "Previous" : "Sebelumnya",
    "Close" : "Tutup",
    "Download" : "Unduh",
    "Toggle background" : "Ubah latar belakang",
    "Delete" : "Hapus",
    "Share" : "Bagikan",
    "Could not create file \"{file}\" because it already exists" : "Tidak dapat membuat berkas \"{file}\" karena sudah ada",
    "Could not create file \"{file}\"" : "Tidak dapat membuat berkas \"{file}\"",
    "\"{name}\" is an invalid file name." : "\"{name}\" adalah nama berkas yang tidak sah.",
    "File name cannot be empty." : "Nama berkas tidak boleh kosong.",
    "Upload" : "Unggah",
    "Error" : "Kesalahan",
    "Error while sharing" : "Kesalahan saat membagikan",
    "Error while unsharing" : "Kesalahan saat membatalkan pembagian",
    "Error while changing permissions" : "Kesalahan saat mengubah izin",
    "Shared with you and the group {group} by {owner}" : "Dibagikan dengan anda dan grup {group} oleh {owner}",
    "Shared with you by {owner}" : "Dibagikan dengan anda oleh {owner}",
    "Share with users or groups …" : "Bagikan dengan pengguna atau grup ...",
    "Share with users, groups or remote users …" : "Bagikan dengan pengguna, grup atau pengguna remote ...",
    "Share link" : "Bagikan tautan",
    "The public link will expire no later than {days} days after it is created" : "Tautan publik akan kadaluarsa tidak lebih dari {days} hari setelah ini dibuat",
    "Link" : "Tautan",
    "Password protect" : "Lindungi dengan kata sandi",
    "Password" : "Kata Sandi",
    "Choose a password for the public link" : "Tetapkan kata sandi untuk tautan publik",
    "Allow editing" : "Izinkan penyuntingan",
    "Email link to person" : "Emailkan tautan ini ke orang",
    "Send" : "Kirim",
    "Set expiration date" : "Atur tanggal kedaluwarsa",
    "Expiration" : "Kedaluwarsa",
    "Expiration date" : "Tanggal kedaluwarsa",
    "Adding user..." : "Menambahkan pengguna...",
    "group" : "grup",
    "remote" : "remote",
    "Resharing is not allowed" : "Berbagi ulang tidak diizinkan",
    "Error while retrieving shares" : "Terjadi kesalahan saat mengambil pembagian",
    "Unshare" : "Batalkan berbagi",
    "notify by email" : "notifikasi via email",
    "can share" : "dapat berbagi",
    "can edit" : "dapat disunting",
    "access control" : "kontrol akses",
    "create" : "buat",
    "change" : "ubah",
    "delete" : "hapus",
    "Password protected" : "Kata sandi dilindungi",
    "Error unsetting expiration date" : "Kesalahan saat menghapus tanggal kedaluwarsa",
    "Error setting expiration date" : "Kesalahan saat mengatur tanggal kedaluwarsa",
    "Email sent" : "Email terkirim",
    "Warning" : "Peringatan",
    "Add to your Nextcloud" : "Tambahkan ke Nextcloud Anda",
    "This share is password-protected" : "Berbagi ini dilindungi kata sandi",
    "The password is wrong. Try again." : "Kata sandi salah. Coba lagi",
    "Cancel upload" : "Batal unggah",
    "Sort by name" : "Urutkan berdasarkan nama",
    "Sort by date" : "Urutkan berdasarkan tanggal",
    "Album information" : "Informasi album",
    "File list" : "Daftar berkas",
    "Sorry, this file could not be found." : "Maaf, berkas ini tidak akan ditemukan.",
    "Reasons might be:" : "Alasan yang mungkin:",
    "the wrong file ID was provided" : "ID berkas yang diberikan salah",
    "the file was removed" : "berkas tersebut telah dihapus",
    "the file is corrupt" : "berkas tersebut rusak",
    "the encryption key is missing" : "kunci enkripsi tidak ada",
    "Here is the error message returned by the server: " : "Disini merupakan pesan kesalahan yang dikembalikan oleh server:",
    "For more information, please contact your friendly Nextcloud administrator." : "Untuk info lebih lanjut, harap hubungi administrator Nextcloud anda.",
    "Sorry, but the server could not fulfill your request." : "Maaf, tetapi server tidak dapat memenuhi permintaan Anda.",
    "Possible reasons for the problem:" : "Penyebab masalah yang mungkin:",
    "a conflicting app was installed" : "sebuah aplikasi yang dipasang menyebabkan konflik",
    "a required component is missing or was disconnected" : "sebuah komponen yang diperlukan tidak ada atau telah terputus",
    "the filesystem is not readable" : "sistem berkas tidak dapat dibaca",
    "Sorry, this link doesn't seem to work anymore." : "Maaf, tautan ini tampaknya tidak bekerja lagi.",
    "the item was removed" : "item telah dihapus",
    "the link has expired" : "tautan telah kadaluarsa",
    "sharing is disabled" : "berbagi dinonaktifkan",
    "For more information, please ask the person who has sent you this link." : "Untuk informasi lebih lanjut, silakan tanyakan pada orang yang telah mengirimkan Anda tautan ini.",
    "Picture view" : "Tampilan gambar",
    "New" : "Baru"
},
"nplurals=1; plural=0;");
